Extract equating table with bootstrap confidence intervals
Source:R/helpers.R
get_equating_table.RdExtracts equating results from a bootstrap object as a clean data frame with log theta values, confidence intervals and standard errors.
Usage
get_equating_table(boot, direction = c("1to2", "2to1"))